@@ -5,11 +5,9 @@ from pathlib import Path
 import tarfile
 import yaml
 from yaml.loader import SafeLoader
-import nzpy
 import warnings
-warnings.filterwarnings('ignore')
-from pyarrow.parquet import ParquetFile
-import pyarrow as pa 
+# warnings.filterwarnings('ignore')
+
 
 
 class ProcessTar(object):
